@@ -1,7 +1,7 @@
 /* This file is part of the KDE libraries
    SPDX-FileCopyrightText: 2001, 2002, 2007 David Faure <faure@kde.org>
 
-   SPDX-License-Identifier: LGPL-2.0-only
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef klimitediodevice_p_h
@@ -28,7 +28,7 @@ public:
      * @param length the length of the data to read (in bytes)
      */
     KLimitedIODevice(QIODevice *dev, qint64 start, qint64 length);
-    virtual ~KLimitedIODevice()
+    ~KLimitedIODevice() override
     {
     }
 
@@ -40,13 +40,15 @@ public:
     qint64 size() const override;
 
     qint64 readData(char *data, qint64 maxlen) override;
-    qint64 writeData(const char *, qint64) override {
-        return -1;    // unsupported
+    qint64 writeData(const char *, qint64) override
+    {
+        return -1; // unsupported
     }
 
-    //virtual qint64 pos() const { return m_dev->pos() - m_start; }
+    // virtual qint64 pos() const { return m_dev->pos() - m_start; }
     bool seek(qint64 pos) override;
     qint64 bytesAvailable() const override;
+
 private:
     QIODevice *m_dev;
     qint64 m_start;
